/*
 * main.cpp
 *
 *  Created on: Aug 2, 2013
 *      Author: peter
 */


#include <hal/I2CBus.h>
#include <hal/I2CSlave.h>
#include <iostream>


using namespace dhcom;
using namespace std;


int main(int argc, char **argv)
{
	I2CBus::BUS busDef;
	if(argc > 1)
	{
		// first arg is an i2c bus
		switch(argv[1][0])
		{
		case '1':
			busDef = I2CBus::BUS_I2C1;
			break;
		case '2':
			busDef = I2CBus::BUS_I2C2;
			break;
		case '3':
			busDef = I2CBus::BUS_I2C3;
			break;
		default:
			cout << "Unknown i2c bus: " << argv[1] << endl;
			return 0;
		}
	}
	else
	{
		busDef = I2CBus::BUS_I2C3;
	}

	uint16_t address;
	if(argc > 2)
	{
		// second arg is the hex address
		sscanf(argv[2], "%hx", &address);
	}
	else
	{
		address = 0x23;
	}

	cout << "Bus: " << int(busDef) << " Address: " << hex << address << dec << endl;

	I2CBus bus(I2CBus::BUS_I2C3);
	I2CSlave device(&bus, address); // 0x23

	STATUS status = bus.open();
	if(status != STATUS_SUCCESS)
	{
		cout << "Cannot open device, status: " << int(status) << endl;
		return 0;
	}

	const uint8_t header[] = {0x01, 0x00}; // In the first byte the r/w flag set to the read, second byte sets the command of reading the input port 0
	uint8_t buffer[2];
	while(true)
	{
		// write the address/rw and the command bytes
		status = device.write(header, sizeof(header));
		if(status == STATUS_SUCCESS)
		{
			status = device.read(buffer, 1);
			if(status != STATUS_SUCCESS)
				cout << "Cannot read device, status: " << int(status) << endl;

			// we read more bytes from the register 0, accordingly to docs we do not need to send another command
			// device.read(buffer, 2);
		}
		else
		{
			cout << "could not write command to device, status: " << int(status) << endl;
		}
	}
}


